@@ -1,6 +1,6 @@
 __all__ = [
     "marg_gkde",
-    "marg_named",
+    "marg_fit",
     "marg_mom",
     "Marginal",
     "MarginalNamed",
@@ -16,6 +16,7 @@ from abc import ABC, abstractmethod
 from numpy import zeros, array, Inf, concatenate, sqrt
 from numpy import min as npmin
 from numpy import max as npmax
+from numpy.random import uniform as runif
 from pandas import DataFrame
 from scipy.optimize import root_scalar, root
 from scipy.stats import alpha, anglit, arcsine, argus, beta, betaprime, \
@@ -257,9 +258,9 @@ class Marginal(ABC):
     def fit(self, data):
         pass
 
-    ## Likelihood function
+    ## Density function
     @abstractmethod
-    def l(self, x):
+    def d(self, x):
         pass
 
     ## Cumulative density function
@@ -272,11 +273,22 @@ class Marginal(ABC):
     def q(self, p):
         pass
 
+    ## Random variable sample
+    def r(self, n):
+        U = runif(size=n)
+        return self.q(U)
+
     ## Summary
     @abstractmethod
     def summary(self):
         pass
 
+    def __str__(self):
+        return self.summary()
+
+    def __repr__(self):
+        return self.summary()
+
 
 ## Named marginal class
 class MarginalNamed(Marginal):
@@ -296,13 +308,13 @@ class MarginalNamed(Marginal):
         return new_marginal
 
     ## Fitting function
-    def fit(self, data):
-        param = valid_dist[self.d_name].fit(data)
+    def fit(self, data, **kwargs):
+        param = valid_dist[self.d_name].fit(data, **kwargs)
         self.d_param = dict(zip(param_dist[dist], param))
 
-    ## Likelihood function
+    ## Density function
     @make_symbolic
-    def l(self, x):
+    def d(self, x):
         return valid_dist[self.d_name].pdf(x, **self.d_param)
 
     ## Cumulative density function
@@ -316,8 +328,16 @@ class MarginalNamed(Marginal):
         return valid_dist[self.d_name].ppf(p, **self.d_param)
 
     ## Summary
-    def summary(self):
-        return "({0:+}) {1:}, {2:}".format(self.sign, self.d_name, self.d_param)
+    def summary(self, dig=2):
+        stats = valid_dist[self.d_name](**self.d_param).stats("mvsk")
+        param = {
+            "mean": "{0:4.3e}".format(stats[0].round(dig)),
+            "s.d.": "{0:4.3e}".format(sqrt(stats[1]).round(dig)),
+            "COV": round(sqrt(stats[1]) / stats[0], dig),
+            "skew.": stats[2].round(dig),
+            "kurt.": stats[3].round(dig) + 3, # full kurtosis
+        }
+        return "({0:+}) {1:}, {2:}".format(self.sign, self.d_name, param)
 
 
 ## Gaussian KDE marginal class
@@ -360,9 +380,9 @@ class MarginalGKDE(Marginal):
         self.kde = gaussian_kde(data)
         self._set_bracket()
 
-    ## Likelihood function
+    ## Density function
     @make_symbolic
-    def l(self, x):
+    def d(self, x):
         return self.kde.pdf(x)
 
     ## Cumulative density function
@@ -423,6 +443,7 @@ def marg_mom(
         skew=None,
         kurt=None,
         kurt_excess=None,
+        floc=None,
         sign=0,
         dict_x0=None,
 ):
@@ -449,6 +470,10 @@ def marg_mom(
         kurt_excess (float): Excess kurtosis of distribution; kurt_excess = kurt - 3.
             Only one of `kurt` and `kurt_excess` can be provided.
 
+        floc (float or None): Frozen value for location parameter
+            Note that for distributions such as "lognorm" or "weibull_min",
+            setting floc=0 selects the 2-parameter version of the distribution.
+
         sign (-1, 0, +1): Sign
         dict_x0 (dict): Dictionary of initial parameter guesses
 
@@ -459,10 +484,12 @@ def marg_mom(
         >>> import grama as gr
         >>> ## Fit a normal distribution
         >>> mg_norm = gr.marg_mom("norm", mean=0, sd=1)
-        >>> ## Fit a lognormal distribution
+        >>> ## Fit a (3-parameter) lognormal distribution
         >>> mg_lognorm = gr.marg_mom("lognorm", mean=1, sd=1, skew=1)
         >>> ## Fit a lognormal, controlling kurtosis instead
         >>> mg_lognorm = gr.marg_mom("lognorm", mean=1, sd=1, kurt=1)
+        >>> ## Fit a 2-parameter lognormal; no skewness or kurtosis needed
+        >>> mg_lognorm = gr.marg_mom("lognorm", mean=1, sd=1, floc=0)
         >>>
         >>> ## Not all moment combinations are feasible; this will fail
         >>> gr.marg_mom("beta", mean=1, sd=1, skew=0, kurt=4)
@@ -477,6 +504,8 @@ def marg_mom(
         raise NotImplementedError(
             "marg_nom does not yet handle distributions with more than 4 parameters"
         )
+    if floc is not None:
+        n_param = n_param - 1
 
     ## Check invariants
     if mean is None:
@@ -529,33 +558,58 @@ def marg_mom(
         )
 
     ## Generate helper function for optimization
-    def _obj(v):
-        kw = dict(zip(param_dist[dist], v))
-        return array(valid_dist[dist](**kw).stats(s)) - m_target
+    if floc is None:
+        key_wk = copy.copy(param_dist[dist])
+    else:
+        key_wk = {key for key in param_dist[dist] if key != "loc"}
+
+    if floc is None:
+        def _obj(v):
+            kw = dict(zip(key_wk, v))
+            return array(valid_dist[dist](**kw).stats(s)) - m_target
+    else:
+        def _obj(v):
+            kw = dict(zip(key_wk, v))
+            kw["loc"] = floc
+            return array(valid_dist[dist](**kw).stats(s)) - m_target
+
 
     ## Generate initial guess
     if dict_x0 is None:
-        # Manually coded initial guesses
-        dict_x0 = dict(
-            loc=mean,
-            scale=sqrt(var),
-            a=1,
-            b=1,
-            s=1,
-            df=10,
-            #K=None,
-            #chi=None,
-        )
+        if dist == "lognorm":
+            dict_x0 = dict(
+                loc=0,
+                scale=mean,
+                s=sqrt(var) / mean,
+            )
+
+        elif dist == "weibull_min":
+            dict_x0 = dict(
+                loc=0,
+                scale=mean,
+                c=1,
+            )
+
+        else:
+            # General-purpose initial guesses
+            dict_x0 = dict(
+                loc=mean,
+                scale=sqrt(var),
+                a=1,
+                b=1,
+                s=1,
+                df=10,
+                c=10,
+                beta=1,
+                #K=None,
+                #chi=None,
+            )
+
     # Repackage for optimizer
-    x0 = array([
-        dict_x0[key] for key in param_dist[dist]
-    ])
+    x0 = array([dict_x0[key] for key in key_wk])
 
     ## Run multidimensional root finding
-    res = root(
-        _obj,
-        x0
-    )
+    res = root(_obj, x0)
 
     ## Check for failed optimization
     if res.success is False:
@@ -566,34 +620,79 @@ def marg_mom(
         )
 
     ## Repackage and return
-    param = dict(zip(param_dist[dist], res.x))
+    param = dict(zip(key_wk, res.x))
+    if floc is not None:
+        param["loc"] = floc
     return MarginalNamed(sign=sign, d_name=dist, d_param=param)
 
 ## Fit a named scipy.stats distribution
-def marg_named(data, dist, name=True, sign=None):
+def marg_fit(dist, data, name=True, sign=None, **kwargs):
     r"""Fit scipy.stats continuous distirbution
 
-    Fits a named scipy.stats continuous distribution. Intended to be used to
-    define a marginal distribution from data.
+    Fits a scipy.stats continuous distribution. Intended to be used to define a
+    marginal distribution from data.
 
-    Args:
-        data (iterable): Data for fit
+    Arguments:
         dist (str): Distribution to fit
+        data (iterable): Data for fit
         name (bool): Include distribution name?
         sign (bool): Include sign? (Optional)
 
+        loc (float): Initial guess for location `loc` parameter (Optional)
+        scale (float): Initial guess for scale `scale` parameter (Optional)
+
+        floc (float): Value to fix the location `loc` parameter (Optional)
+            Note that for distributions such as "lognorm" or "weibull_min",
+            setting floc=0 selects the 2-parameter version of the distribution.
+        fscale (float): Value to fix the location `scale` parameter (Optional)
+        f* (float): Value to fix the specified shape parameter (Optional)
+            e.g. give fc to fix the `c` parameter
+
     Returns:
         gr.MarginalNamed: Distribution
 
     Examples:
 
         >>> import grama as gr
-        >>> from grama.data import df_stang
-        >>>     gr.cp_marginals(
-        >>>         E=gr.marg_named(df_stang.E, "norm"),
-        >>>         mu=gr.marg_named(df_stang.mu, "beta")
+        >>> from grama.data import df_shewhart
+        >>> # Fit normal distribution
+        >>> mg_normal = gr.marg_named(
+        >>>     "norm",
+        >>>     df_shewhart.tensile_strength,
+        >>> )
+        >>> # Fit two-parameter Weibull distribution
+        >>> mg_weibull2 = gr.marg_named(
+        >>>     "weibull_min",
+        >>>     df_shewhart.tensile_strength,
+        >>>     floc=0,        # 2-parameter has frozen loc == 0
+        >>> )
+        >>> # Fit three-parameter Weibull distribution
+        >>> mg_weibull3 = gr.marg_named(
+        >>>     "weibull_min",
+        >>>     df_shewhart.tensile_strength,
+        >>>     loc=0,        # 3-parameter fit tends to be unstable;
+        >>>                   # an inital guess helps stabilize fit
+        >>> )
+        >>> # Inspect fits with QQ plot
+        >>> (
+        >>>     df_shewhart
+        >>>     >> gr.tf_mutate(
+        >>>         q_normal=gr.qqvals(DF.tensile_strength, marg=mg_normal),
+        >>>         q_weibull2=gr.qqvals(DF.tensile_strength, marg=mg_weibull2),
         >>>     )
-        >>> md.printpretty()
+        >>>     >> gr.tf_pivot_longer(
+        >>>         columns=[
+        >>>             "q_normal",
+        >>>             "q_weibull2",
+        >>>         ],
+        >>>         names_to=[".value", "Distribution"],
+        >>>         names_sep="_"
+        >>>     )
+        >>>
+        >>>     >> gr.ggplot(gr.aes("q", "tensile_strength"))
+        >>>     + gr.geom_abline(intercept=0, slope=1, linetype="dashed")
+        >>>     + gr.geom_point(gr.aes(color="Distribution"))
+        >>> )
 
     """
     ## Catch case where user provides entire DataFrame
@@ -603,7 +702,7 @@ def marg_named(data, dist, name=True, sign=None):
     ## Fit the distribution
     with warnings.catch_warnings():
         warnings.simplefilter("ignore")
-        param = valid_dist[dist].fit(data)
+        param = valid_dist[dist].fit(data, **kwargs)
 
     param = dict(zip(param_dist[dist], param))
 
