@@ -4,6 +4,7 @@ __all__ = [
     "custom_formatwarning",
     "df_equal",
     "df_make",
+    "df_grid",
     "param_dist",
     "pipe",
     "valid_dist",
@@ -316,7 +317,10 @@ def add_pipe(fun):
 ## Safe length-checker
 def safelen(x):
     try:
+        if isinstance(x, str):
+            raise TypeError
         return len(x)
+
     except TypeError:
         return 1
 
@@ -444,6 +448,15 @@ def tran_outer(df, df_outer):
         >>> 3  2  4
 
     """
+    # Check invariants
+    if (df.shape[0] == 0) and (df_outer.shape[0] == 0):
+        raise ValueError("At least one of df and df_outer must be non-empty")
+    # Handle single-empty cases
+    if (df.shape[0] == 0):
+        return df_outer
+    if (df_outer.shape[0] == 0):
+        return df
+
     n_rows = df.shape[0]
     list_df = []
 
@@ -455,3 +468,39 @@ def tran_outer(df, df_outer):
 
 
 tf_outer = add_pipe(tran_outer)
+
+
+## DataFrame constructor utility; outer product
+def df_grid(**kwargs):
+    r"""Construct a DataFrame as outer-product
+
+    Helper function to construct a DataFrame as an outer-product of the given
+    columns.
+
+    Keyword Args:
+        varname (iterable): Column for constructed dataframe; column
+                            name inferred from variable name.
+    Returns:
+        DataFrame: Constructed DataFrame
+
+    Preconditions:
+        All provided variable names (keyword arguments) must be distinct.
+
+    Examples:
+        A common use-case is to use df_grid() to define a sweep across variables.
+
+
+    """
+    ## Construct dataframe
+    df_res = DataFrame()
+    for key in kwargs.keys():
+        # Switch based on argument length
+        l = safelen(kwargs[key])
+        if l == 1:
+            df_tmp = DataFrame(columns=[key], data=[kwargs[key]])
+        else:
+            df_tmp = DataFrame(columns=[key], data=kwargs[key])
+
+        df_res = tran_outer(df_res, df_outer=df_tmp)
+
+    return df_res
